@@ -17,12 +17,13 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef LANCELOT_LAUNCHER_APPLET_H_
-#define LANCELOT_LAUNCHER_APPLET_H_
+#ifndef LANCELOT_APPLET_H
+#define LANCELOT_APPLET_H
 
 #include <plasma/applet.h>
 #include <KConfigDialog>
 #include <QString>
+#include <QPainter>
 #include "LancelotAppletConfig.h"
 #include "../LancelotConfig.h"
 
@@ -37,6 +38,8 @@ public:
     void init();
     virtual QList< QAction * > contextualActions();
 
+    // void paint(QPainter *, const QStyleOptionGraphicsItem *, QWidget *);
+
 protected Q_SLOTS:
     void showLancelot();
     void toggleLancelot();
@@ -45,6 +48,7 @@ protected Q_SLOTS:
     void configAccepted();
 
 protected:
+    virtual QSizeF sizeHint(Qt::SizeHint which, const QSizeF & constraint = QSizeF()) const;
     virtual void createConfigurationInterface(KConfigDialog *parent);
     virtual void constraintsEvent(Plasma::Constraints
             constraints);
