@@ -17,10 +17,10 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef LANCELOTAPP_MODELS_BASEMODEL_H_
-#define LANCELOTAPP_MODELS_BASEMODEL_H_
+#ifndef LANCELOTAPP_MODELS_BASEMODEL_H
+#define LANCELOTAPP_MODELS_BASEMODEL_H
 
-#include <lancelot/models/ActionListViewModels.h>
+#include <lancelot/models/StandardActionListModel.h>
 #include <KService>
 #include <KUrl>
 
@@ -30,30 +30,41 @@ class ApplicationConnector: public QObject {
     Q_OBJECT
 public:
     static ApplicationConnector * instance();
+
     void search(const QString & search);
-    bool hide(bool immediate = false);
+    void hide(bool immediate = false);
+
+    void setAutohideEnabled(bool value);
+    bool autohideEnabled() const;
 
 Q_SIGNALS:
     void doSearch(const QString & search);
-    bool doHide(bool immediate);
+    void doHide(bool immediate);
 
 private:
     ApplicationConnector();
     ~ApplicationConnector();
 
     static ApplicationConnector * m_instance;
+
+    class Private;
+    Private * const d;
 };
 
-class BaseModel : public Lancelot::StandardActionListViewModel {
+class BaseModel : public Lancelot::StandardActionListModel {
     Q_OBJECT
 public:
     BaseModel(bool enableDefaultDnD = false);
     virtual ~BaseModel();
 
-    L_Override virtual QMimeData * mimeData(int index) const;
-    L_Override virtual void setDropActions(int index,
+    L_Override QMimeData * mimeData(int index) const;
+    L_Override void setDropActions(int index,
             Qt::DropActions & actions, Qt::DropAction & defaultAction);
 
+    L_Override QString selfTitle() const;
+    L_Override QIcon selfIcon() const;
+    L_Override QMimeData * selfMimeData() const;
+
 protected:
     virtual void activate(int index);
     virtual void load() = 0;
@@ -68,8 +79,12 @@ protected:
 
     int addUrls(const QStringList & urls);
 
-    void hideLancelotWindow();
-    void changeLancelotSearchString(const QString & string);
+    static void hideLancelotWindow();
+    static void changeLancelotSearchString(const QString & string);
+
+    void setSelfTitle(const QString & title);
+    void setSelfIcon(const QIcon & icon);
+    void setSelfMimeData(QMimeData * data);
 
 public:
     static QMimeData * mimeForUrl(const KUrl & url);
@@ -79,9 +94,10 @@ public:
     static QMimeData * mimeForService(const QString & service);
 
 private:
-    bool m_enableDefaultDnD;
+    class Private;
+    Private * const d;
 };
 
 } // namespace Models
 
-#endif /* LANCELOTAPP_MODELS_BASEMODEL_H_ */
+#endif /* LANCELOTAPP_MODELS_BASEMODEL_H */
