@@ -17,23 +17,23 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef LANCELOTAPP_MODELS_PLACES_H_
-#define LANCELOTAPP_MODELS_PLACES_H_
+#ifndef LANCELOTAPP_MODELS_PLACES_H
+#define LANCELOTAPP_MODELS_PLACES_H
 
-#include "BaseModel.h"
+#include "XbelModel.h"
 
 namespace Models {
 
-class Places : public BaseModel {
+class Places : public XbelModel {
     Q_OBJECT
 public:
     Places();
     virtual ~Places();
 
-protected:
-    void load();
+// protected:
+//     void load();
 };
 
 } // namespace Models
 
-#endif /* LANCELOTAPP_MODELS_PLACES_H_ */
+#endif /* LANCELOTAPP_MODELS_PLACES_H */
