@@ -17,8 +17,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef LANCELOT_NODE_LAYOUT_H_
-#define LANCELOT_NODE_LAYOUT_H_
+#ifndef LANCELOT_NODE_LAYOUT_H
+#define LANCELOT_NODE_LAYOUT_H
 
 #include <QtCore/QMap>
 #include <cmath>
@@ -102,11 +102,11 @@ public:
     void addItem(QGraphicsLayoutItem * item,
             NodeCoordinate node, qreal xr = 0, qreal yr = 0);
 
-    L_Override virtual void setGeometry(const QRectF & rect);
-    L_Override virtual int count() const;
-    L_Override virtual QGraphicsLayoutItem * itemAt(int i) const;
-    L_Override virtual void removeAt(int index);
-    L_Override virtual QSizeF sizeHint(Qt::SizeHint which,
+    L_Override void setGeometry(const QRectF & rect);
+    L_Override int count() const;
+    L_Override QGraphicsLayoutItem * itemAt(int i) const;
+    L_Override void removeAt(int index);
+    L_Override QSizeF sizeHint(Qt::SizeHint which,
             const QSizeF & constraint = QSizeF()) const;
 
 private:
@@ -116,5 +116,5 @@ private:
 
 } // namespace Lancelot
 
-#endif /* LANCELOT_NODE_LAYOUT_H_ */
+#endif /* LANCELOT_NODE_LAYOUT_H */
 
