@@ -18,7 +18,6 @@
  */
 
 #include "Panel.h"
-#include <KDebug>
 #include "BasicWidget.h"
 #include <plasma/framesvg.h>
 
@@ -29,7 +28,7 @@ class Panel::Private {
 public:
     Private(QIcon icon, QString title, Panel * parent)
       : layoutItem(NULL),
-        hasTitle(title != QString()),
+        hasTitle(!title.isEmpty()),
         titleWidget(icon, title, "", parent),
         q(parent)
     {
@@ -38,7 +37,7 @@ public:
 
     Private(QString title, Panel * parent)
       : layoutItem(NULL),
-        hasTitle(title != QString()),
+        hasTitle(!title.isEmpty()),
         titleWidget(title, "", parent),
         q(parent)
     {
@@ -60,6 +59,7 @@ public:
 
     void init()
     {
+        showingTitle = hasTitle;
         titleWidget.setIconSize(QSize(16, 16));
         titleWidget.setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
         titleWidget.setEnabled(false);
@@ -76,7 +76,7 @@ public:
             rect.setHeight(rect.height() - q->group()->backgroundSvg()->marginSize(Plasma::BottomMargin));
         }
 
-        if (!hasTitle) {
+        if (!showingTitle || !hasTitle) {
             titleWidget.hide();
             if (layoutItem) {
                 layoutItem->setGeometry(rect);
@@ -99,6 +99,7 @@ public:
 
     QGraphicsLayoutItem * layoutItem;
     bool hasTitle;
+    bool showingTitle;
 
     BasicWidget titleWidget;
     Panel * q;
@@ -130,7 +131,7 @@ Panel::~Panel()
     delete d;
 }
 
-qreal Panel::borderSize(Plasma::MarginEdge edge)
+qreal Panel::borderSize(Plasma::MarginEdge edge) const
 {
     if (!(group()) || !(group()->backgroundSvg())) {
         return 0;
@@ -169,6 +170,17 @@ QSize Panel::iconSize() const
     return d->titleWidget.iconSize();
 }
 
+void Panel::setShowingTitle(bool value)
+{
+    d->showingTitle = value;
+    d->titleWidget.setVisible(value);
+}
+
+bool Panel::isShowingTitle() const
+{
+    return d->showingTitle;
+}
+
 void Panel::setGeometry(const QRectF & geometry)
 {
     Widget::setGeometry(geometry);
@@ -187,7 +199,7 @@ void Panel::setLayoutItem(QGraphicsLayoutItem * layoutItem)
     d->invalidate();
 }
 
-QGraphicsLayoutItem * Panel::layoutItem()
+QGraphicsLayoutItem * Panel::layoutItem() const
 {
     return d->layoutItem;
 }
