@@ -272,7 +272,7 @@ Notes::Notes(QObject *parent, const QVariantList &args)
     m_layout->addItem(m_textEdit);
 
     if (args.count() > 0) {
-        KUrl url = KUrl::fromPathOrUrl(args.at(0).toString());
+        KUrl url = KUrl(args.at(0).toString());
         QFile f(url.path());
 
         if (f.open(QIODevice::ReadOnly)) {
@@ -323,9 +323,6 @@ void Notes::init()
     m_textColor = cg.readEntry("textColor", QColor(Qt::black));
     m_textBackgroundColor = cg.readEntry("textBackgroundColor", QColor(Qt::transparent));
     m_textEdit->nativeWidget()->setTextColor(m_textColor);
-    QPalette palette = m_textEdit->nativeWidget()->palette();
-    palette.setColor(QPalette::Text, m_textColor);
-    m_textEdit->nativeWidget()->setPalette(palette);
 
     QString text = cg.readEntry("autoSaveHtml", QString());
     if (text.isEmpty()) {
@@ -346,6 +343,12 @@ void Notes::init()
     }
 
     m_font = cg.readEntry("font", KGlobalSettings::generalFont());
+    //Set the font family on init, it may have changed from the outside
+    QTextCursor oldCursor = m_textEdit->nativeWidget()->textCursor();
+    m_textEdit->nativeWidget()->selectAll();
+    m_textEdit->nativeWidget()->setFontFamily(m_font.family());
+    m_textEdit->nativeWidget()->setTextCursor(oldCursor);
+    
     m_customFontSize = cg.readEntry("customFontSize", m_font.pointSize());
     m_autoFont = cg.readEntry("autoFont", true);
     m_autoFontPercent = cg.readEntry("autoFontPercent", 4);
@@ -368,6 +371,14 @@ void Notes::init()
 */
 void Notes::lineChanged()
 {
+    //Re-set the formatting if previous text was deleted
+    if (m_textEdit->nativeWidget()->document()->characterCount() == 1) {
+        QTextCharFormat fmt;
+        fmt.setForeground(QBrush(m_textColor));
+        fmt.setFont(m_font);
+        m_textEdit->nativeWidget()->setCurrentCharFormat(fmt);   
+    }
+    
     if (m_useNoColor) {
         return;
     }
@@ -411,7 +422,15 @@ void Notes::updateTextGeometry()
         const qreal ypad = geometry().height() / 15;
         m_layout->setContentsMargins(xpad, ypad, xpad, ypad);
         m_font.setPointSize(fontSize());
-        m_textEdit->nativeWidget()->setFont(m_font);
+
+        QTextCursor oldTextCursor = m_textEdit->nativeWidget()->textCursor();
+        m_textEdit->nativeWidget()->selectAll();
+        m_textEdit->nativeWidget()->setFontPointSize(m_font.pointSize());
+        m_textEdit->nativeWidget()->setTextCursor(oldTextCursor);
+        
+        if (m_autoFont) {
+            lineChanged();
+        }
     }
 }
 
@@ -511,9 +530,9 @@ void Notes::createConfigurationInterface(KConfigDialog *parent)
 
     ui.textColorButton->setColor(m_textColor);
     ui.textBackgroundColorButton->setColor(m_textBackgroundColor);
-    ui.fontStyleComboBox->setCurrentFont(m_textEdit->nativeWidget()->font());
-    ui.fontBoldCheckBox->setChecked(m_textEdit->nativeWidget()->font().bold());
-    ui.fontItalicCheckBox->setChecked(m_textEdit->nativeWidget()->font().italic());
+    ui.fontStyleComboBox->setCurrentFont(m_font);
+    ui.fontBoldCheckBox->setChecked(m_font.bold());
+    ui.fontItalicCheckBox->setChecked(m_font.italic());
     ui.autoFont->setChecked(m_autoFont);
     ui.autoFontPercent->setEnabled(m_autoFont);
     ui.customFont->setChecked(!m_autoFont);
@@ -555,35 +574,53 @@ void Notes::configAccepted()
     QFont newFont = ui.fontStyleComboBox->currentFont();
     newFont.setBold(ui.fontBoldCheckBox->isChecked());
     newFont.setItalic(ui.fontItalicCheckBox->isChecked());
+    
+    //Apply bold and italic changes (if any) here (this is destructive formatting)
+    bool boldChanged = (m_font.bold() != newFont.bold());
+    bool italicChanged = (m_font.italic() != newFont.italic());
+    if (boldChanged || italicChanged) {
+        //Save previous selection
+        QTextCursor oldCursor = m_textEdit->nativeWidget()->textCursor();
+        m_textEdit->nativeWidget()->selectAll();
+        if (boldChanged) {
+            m_textEdit->nativeWidget()->setFontWeight(newFont.weight());
+        }
+        if (italicChanged) {
+            m_textEdit->nativeWidget()->setFontItalic(newFont.italic());
+        }
+        //Restore previous selection
+        m_textEdit->nativeWidget()->setTextCursor(oldCursor);
+    }
+    
+    //Save font settings to config
     if (m_font != newFont) {
         changed = true;
         cg.writeEntry("font", newFont);
         m_font = newFont;
-        m_font.setPointSize(fontSize());
-        m_textEdit->nativeWidget()->setFont(newFont);
+        
+        //Apply font size
+        QTextCursor oldCursor = m_textEdit->nativeWidget()->textCursor();
+        m_textEdit->nativeWidget()->selectAll();
+        m_textEdit->nativeWidget()->setFontFamily(m_font.family());
+        m_textEdit->nativeWidget()->setTextCursor(oldCursor);
     }
 
     if (m_customFontSize != ui.customFontSizeSpinBox->value()) {
         changed = true;
         m_customFontSize = ui.customFontSizeSpinBox->value();
         cg.writeEntry("customFontSize", m_customFontSize);
-        m_font.setPointSize(fontSize());
     }
 
     if (m_autoFont != ui.autoFont->isChecked()) {
         changed = true;
         m_autoFont = ui.autoFont->isChecked();
         cg.writeEntry("autoFont", m_autoFont);
-        m_font.setPointSize(fontSize());
     }
 
     if (m_autoFontPercent != ui.autoFontPercent->value()) {
         changed = true;
         m_autoFontPercent = (ui.autoFontPercent->value());
         cg.writeEntry("autoFontPercent", m_autoFontPercent);
-        if (m_autoFont) {
-            m_font.setPointSize(fontSize());
-        }
     }
 
     //TODO
@@ -602,9 +639,6 @@ void Notes::configAccepted()
         m_textEdit->nativeWidget()->selectAll();
         m_textEdit->nativeWidget()->setTextColor(m_textColor);
         m_textEdit->nativeWidget()->setTextCursor(textCursor);
-        QPalette palette = m_textEdit->nativeWidget()->palette();
-        palette.setColor(QPalette::Text, m_textColor);
-        m_textEdit->nativeWidget()->setPalette(palette);
     }
 
     if (m_useNoColor != ui.useNoColor->isChecked()) {
